# mlw-cli
Command Line Interface for mlworks python package

[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg?style=flat)](https://github.com/adelmofilho/mlw-cli/issues)
[![Project Status: WIP – Initial development is in progress, but there has not yet been a stable, usable release suitable for the public.](https://www.repostatus.org/badges/latest/wip.svg)](https://www.repostatus.org/#wip)
[![pypi](https://img.shields.io/pypi/v/mlw-cli)](https://pypi.org/project/mlw-cli/)
[![python](https://img.shields.io/pypi/pyversions/mlw-cli)](https://pypi.org/project/mlw-cli/)
[![license](https://img.shields.io/github/license/adelmofilho/mlw-cli?color=blue)]()
[![Code Quality](https://img.shields.io/scrutinizer/g/adelmofilho/mlw-cli.svg)](https://scrutinizer-ci.com/g/adelmofilho/mlw-cli/badges/quality-score.png?b=master)
[![Build Status](https://api.travis-ci.org/adelmofilho/mlw-cli.svg?branch=master&status=unknown)](https://travis-ci.org/github/adelmofilho/mlw-cli/)
[![codecov](https://codecov.io/gh/adelmofilho/mlw-cli/branch/master/graphs/badge.svg?branch=master)](https://codecov.io/github/adelmofilho/mlw-cli?branch=master)
[![docs](https://readthedocs.org/projects/mlw-cli/badge/?version=latest)](https://readthedocs.org/projects/mlw-cli/?badge=latest)
[![Upload PyPI](https://github.com/adelmofilho/mlw-cli/workflows/Upload%20Python%20Package/badge.svg)](https://github.com/adelmofilho/mlw-cli/actions)
![Python package](https://github.com/adelmofilho/mlw-cli/workflows/Python%20package/badge.svg)
